#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "../vipipc.h"
#include "../vipipc_prototypes.h"

#define DEFAULT_MIME_TYPE "video/mpeg"

void usage(const char* myname) {
	fprintf(stderr, "usage: %s <URI> [<MIME>]\n"
			"\tloads given URI, with app triggered by optional MIME type.\n"
			"\tMIME type defaults to \"" DEFAULT_MIME_TYPE "\".\n", myname);
	exit(1);
}

int main(int argc, char* argv[]) {
	int err;
	ipcconn ns, uls;

	/* we are (most probably) not run by appman */

	if(argc < 2) usage(argv[0]);

	ns = ipcconn_get_nameservice();
	if(!ns) {
		fprintf(stderr, "error creating nameservice ipcconn\n");
		exit(1);
	}

	uls = UriLoaderService_new(ns);
	if(!uls) {
		fprintf(stderr, "error creating uriloaderservice ipcconn\n");
		ipcconn_free(&ns);
		exit(2);
	}

	err = UriLoaderService_LoadUri(uls, argv[1], (argc < 2) ? DEFAULT_MIME_TYPE : argv[2]);
	if(err)
		fprintf(stderr, "error %d when trying to load URI.\n", err);

	ipcconn_free(&uls);
	ipcconn_free(&ns);
	exit(err);
}

